ENTRY_POINT_GROUP = 'extensions'
ENV_OPTION_PREFIX = 'PY_EXTENSION_BUILDER_'
